#!/usr/bin/perl -w
use User::pwent;
use Getopt::Long;
use Pod::Usage;

=pod

=head1 NAME

afs_user_distribute.pl - redistribute users volumes evenly to AFS servers

=head1 DESCRIPTION

Redistribute users home volumes based on their UID evenly on all available
AFS file servers. Goal is to distribute the strain on servers when a class
starts in any of our computer labs.

=head1 OPTIONS

=over

=item -?, --help, --man

show a short help screen or the manual page

=item --uid_start <number>

ignore UIDs smaller than <number>

=item --uid_stop <number>

ignore UIDs bigger than <number>

=item --run|-r

Execute the necessary statements, otherwise just show the basic AFS commands
to perform the move.

=back

=cut

my $execute=0;
my $UID_start=5300;
my $UID_stop =10000;
my @excludeservers;
GetOptions('run|r'       => \$execute,
	   'uid_start=i' => \$UID_start,
	   'uid_stop=i'  => \$UID_stop,
           'help|?'      => sub{pod2usage(-exitstatus => 0, -verbose => 1)},
           'man'         => sub{pod2usage(-exitstatus => 0, -verbose => 2)})
  or pod2usage(-exitstatus => 0, -verbose => 2);

my $cnt=0;
my @servers=("faepsv00.tu-graz.ac.at",
	     "faepsv03.tu-graz.ac.at",
	     "faepsv06.tu-graz.ac.at",
	     "faepsv09.tu-graz.ac.at");
my $srv_cnt=@servers;


while ($user = getpwent()) {
    next if ($user->uid  < $UID_start);
    next if ($user->uid  > $UID_stop);
    next if ($user->gid != 550);
    $cnt+=1;
    $uname = $user->name;
    #    print "# " .  $user->name . "\t" . $user->uid . ":" . $user->gid . "\t\n" ;
    $server= $servers[$user->uid % $srv_cnt];
    if ($execute) {
	`afs_volume_move --run --include $server user.$uname`;
    } else {
	print "afs_volume_move --run --include $server user.$uname \t# UID: " . $user->uid . "\n";
    }
}

=pod

=head1 BUGS

None!

=head1 LICENSE

Copyright 20016/2018, Andreas Hirczy <ahi@itp.tugraz.at>

This program is distributed under the GNU General Public License and is
available as part of B<afs_admin_tools> from
I<http://itp.tugraz.at/~ahi/Computer/SW/>

=head2 GNU General Public License

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA

=cut
